/*
 * Copyright (C) 2007 Andre Beckedorf <evilJazz _AT_ katastrophos _DOT_ net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <unistd.h>
#include <qpe/qpeapplication.h>
#include <qdir.h>
#include <qmessagebox.h>
#include "wm8750mixer.h"

int main(int argc, char **argv)
{
	QPEApplication app(argc, argv);

	// check whether the kernel patch is installed...
	if (!QDir("/proc/driver/wm8750").exists())
	{
		QMessageBox::critical(0, "Enhanced WM8750 driver not present", 
				"Your kernel does not feature the required\n"
				"functionality for this application.\n\n"
				"Please download the required kernel patches\n"
				"from:\n\n"
				"http://www.katastrophos.net/zaurus/sources/wm8750mixer");
	
		return 1;
	}	

	// check whether the effective user is is super-user...
	if (geteuid() != 0)
	{
		QMessageBox::critical(0, "WM8750Mixer read-only mode activated", 
				"You are running this application as normal user.\n"
				"In order to change settings, please execute this\n"
				"application with root privileges.\n"
				"To do so please change the shortcut manually in\n"
				"the Qtopia Launcher (long-click on app icon).");
	}
	
	WM8750Mixer *mainWidget = new WM8750Mixer();
	app.showMainWidget(mainWidget);
	
	int result = app.exec();
	
	return result;
}

